@@ -37,15 +37,12 @@ struct _AdwExpanderRowClass
 ADW_AVAILABLE_IN_ALL
 GtkWidget *adw_expander_row_new (void) G_GNUC_WARN_UNUSED_RESULT;
 
-ADW_DEPRECATED_IN_1_4_FOR (adw_expander_row_add_suffix)
+ADW_AVAILABLE_IN_ALL
 void adw_expander_row_add_action (AdwExpanderRow *self,
                                   GtkWidget      *widget);
 ADW_AVAILABLE_IN_ALL
 void adw_expander_row_add_prefix (AdwExpanderRow *self,
                                   GtkWidget      *widget);
-ADW_AVAILABLE_IN_1_4
-void adw_expander_row_add_suffix (AdwExpanderRow *self,
-                                  GtkWidget      *widget);
 
 ADW_AVAILABLE_IN_ALL
 void adw_expander_row_add_row    (AdwExpanderRow *self,
@@ -85,15 +82,15 @@ void     adw_expander_row_set_show_enable_switch (AdwExpanderRow *self,
                                                   gboolean        show_enable_switch);
 
 ADW_AVAILABLE_IN_1_3
-int  adw_expander_row_get_title_lines (AdwExpanderRow *self);
+gboolean adw_expander_row_get_title_lines (AdwExpanderRow *self);
 ADW_AVAILABLE_IN_1_3
-void adw_expander_row_set_title_lines (AdwExpanderRow *self,
-                                       int             title_lines);
+void     adw_expander_row_set_title_lines (AdwExpanderRow *self,
+                                           int             title_lines);
 
 ADW_AVAILABLE_IN_1_3
-int  adw_expander_row_get_subtitle_lines (AdwExpanderRow *self);
+gboolean adw_expander_row_get_subtitle_lines (AdwExpanderRow *self);
 ADW_AVAILABLE_IN_1_3
-void adw_expander_row_set_subtitle_lines (AdwExpanderRow *self,
-                                          int             subtitle_lines);
+void     adw_expander_row_set_subtitle_lines (AdwExpanderRow *self,
+                                              int             subtitle_lines);
 
 G_END_DECLS
