@@ -193,6 +193,21 @@ indicator_clicked_cb (AdwTabThumbnail *self)
   g_signal_emit_by_name (self->view, "indicator-activated", self->page);
 }
 
+static GdkDragAction
+make_action_unique (GdkDragAction actions)
+{
+  if (actions & GDK_ACTION_COPY)
+    return GDK_ACTION_COPY;
+
+  if (actions & GDK_ACTION_MOVE)
+    return GDK_ACTION_MOVE;
+
+  if (actions & GDK_ACTION_LINK)
+    return GDK_ACTION_LINK;
+
+  return 0;
+}
+
 static gboolean
 drop_cb (AdwTabThumbnail *self,
          GValue          *value)
@@ -210,6 +225,7 @@ extra_drag_enter_cb (AdwTabThumbnail *self)
   const GValue *value = gtk_drop_target_get_value (self->drop_target);
 
   g_signal_emit (self, signals[SIGNAL_EXTRA_DRAG_VALUE], 0, value, &self->preferred_action);
+  self->preferred_action = make_action_unique (self->preferred_action);
 
   return self->preferred_action;
 }
@@ -226,21 +242,7 @@ extra_drag_notify_value_cb (AdwTabThumbnail *self)
   const GValue *value = gtk_drop_target_get_value (self->drop_target);
 
   g_signal_emit (self, signals[SIGNAL_EXTRA_DRAG_VALUE], 0, value, &self->preferred_action);
-}
-
-static GdkDragAction
-make_action_unique (GdkDragAction actions)
-{
-  if (actions & GDK_ACTION_COPY)
-    return GDK_ACTION_COPY;
-
-  if (actions & GDK_ACTION_MOVE)
-    return GDK_ACTION_MOVE;
-
-  if (actions & GDK_ACTION_LINK)
-    return GDK_ACTION_LINK;
-
-  return 0;
+  self->preferred_action = make_action_unique (self->preferred_action);
 }
 
 static void
@@ -730,6 +732,8 @@ adw_tab_thumbnail_fade_out (AdwTabThumbnail *self)
   g_return_if_fail (ADW_IS_TAB_THUMBNAIL (self));
 
   adw_animation_reset (self->fade_animation);
+
+  gtk_widget_set_opacity (self->overlay, 0);
 }
 
 void
@@ -737,5 +741,7 @@ adw_tab_thumbnail_fade_in (AdwTabThumbnail *self)
 {
   g_return_if_fail (ADW_IS_TAB_THUMBNAIL (self));
 
+  gtk_widget_set_opacity (self->overlay, 1);
+
   adw_animation_play (self->fade_animation);
 }
