@@ -45,9 +45,6 @@
  * [property@Toast:priority] determines how it behaves if another toast is
  * already being displayed.
  *
- * Toast titles use Pango markup by default, set [property@Toast:use-markup] to
- * `FALSE` if this is unwanted.
- *
  * [property@Toast:custom-title] can be used to replace the title label with a
  * custom widget.
  *
@@ -157,7 +154,6 @@ struct _AdwToast {
   AdwToastPriority priority;
   guint timeout;
   GtkWidget *custom_title;
-  gboolean use_markup;
 
   AdwToastOverlay *overlay;
 };
@@ -171,8 +167,7 @@ enum {
   PROP_PRIORITY,
   PROP_TIMEOUT,
   PROP_CUSTOM_TITLE,
-  PROP_USE_MARKUP,
-  LAST_PROP
+  LAST_PROP,
 };
 
 static GParamSpec *props[LAST_PROP];
@@ -246,9 +241,6 @@ adw_toast_get_property (GObject    *object,
   case PROP_CUSTOM_TITLE:
     g_value_set_object (value, adw_toast_get_custom_title (self));
     break;
-  case PROP_USE_MARKUP:
-    g_value_set_boolean (value, adw_toast_get_use_markup (self));
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -284,9 +276,6 @@ adw_toast_set_property (GObject      *object,
   case PROP_CUSTOM_TITLE:
     adw_toast_set_custom_title (self, g_value_get_object (value));
     break;
-  case PROP_USE_MARKUP:
-    adw_toast_set_use_markup (self, g_value_get_boolean (value));
-    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
@@ -303,7 +292,7 @@ adw_toast_class_init (AdwToastClass *klass)
   object_class->set_property = adw_toast_set_property;
 
   /**
-   * AdwToast:title:
+   * AdwToast:title: (attributes org.gtk.Property.get=adw_toast_get_title org.gtk.Property.set=adw_toast_set_title)
    *
    * The title of the toast.
    *
@@ -319,7 +308,7 @@ adw_toast_class_init (AdwToastClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwToast:button-label:
+   * AdwToast:button-label: (attributes org.gtk.Property.get=adw_toast_get_button_label org.gtk.Property.set=adw_toast_set_button_label)
    *
    * The label to show on the button.
    *
@@ -335,7 +324,7 @@ adw_toast_class_init (AdwToastClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwToast:action-name:
+   * AdwToast:action-name: (attributes org.gtk.Property.get=adw_toast_get_action_name org.gtk.Property.set=adw_toast_set_action_name)
    *
    * The name of the associated action.
    *
@@ -349,7 +338,7 @@ adw_toast_class_init (AdwToastClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwToast:action-target: (getter get_action_target_value) (setter set_action_target_value)
+   * AdwToast:action-target: (attributes org.gtk.Property.get=adw_toast_get_action_target_value org.gtk.Property.set=adw_toast_set_action_target_value)
    *
    * The parameter for action invocations.
    */
@@ -360,7 +349,7 @@ adw_toast_class_init (AdwToastClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwToast:priority:
+   * AdwToast:priority: (attributes org.gtk.Property.get=adw_toast_get_priority org.gtk.Property.set=adw_toast_set_priority)
    *
    * The priority of the toast.
    *
@@ -379,7 +368,7 @@ adw_toast_class_init (AdwToastClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwToast:timeout:
+   * AdwToast:timeout: (attributes org.gtk.Property.get=adw_toast_get_timeout org.gtk.Property.set=adw_toast_set_timeout)
    *
    * The timeout of the toast, in seconds.
    *
@@ -395,7 +384,7 @@ adw_toast_class_init (AdwToastClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwToast:custom-title:
+   * AdwToast:custom-title: (attributes org.gtk.Property.get=adw_toast_get_custom_title org.gtk.Property.set=adw_toast_set_custom_title)
    *
    * The custom title widget.
    *
@@ -411,20 +400,6 @@ adw_toast_class_init (AdwToastClass *klass)
                          GTK_TYPE_WIDGET,
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
-  /**
-   * AdwToast:use-markup:
-   *
-   * Whether to use Pango markup for the toast title.
-   *
-   * See also [func@Pango.parse_markup].
-   *
-   * Since: 1.4
-   */
-  props[PROP_USE_MARKUP] =
-    g_param_spec_boolean ("use-markup", NULL, NULL,
-                          TRUE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
-
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
   /**
@@ -473,7 +448,6 @@ adw_toast_init (AdwToast *self)
   self->priority = ADW_TOAST_PRIORITY_NORMAL;
   self->timeout = 5;
   self->custom_title = NULL;
-  self->use_markup = TRUE;
 
   g_signal_connect (self, "dismissed", G_CALLBACK (dismissed_cb), self);
 }
@@ -537,7 +511,7 @@ adw_toast_new_format (const char *format,
 }
 
 /**
- * adw_toast_get_title:
+ * adw_toast_get_title: (attributes org.gtk.Method.get_property=title)
  * @self: a toast
  *
  * Gets the title that will be displayed on the toast.
@@ -559,7 +533,7 @@ adw_toast_get_title (AdwToast *self)
 }
 
 /**
- * adw_toast_set_title:
+ * adw_toast_set_title: (attributes org.gtk.Method.set_property=title)
  * @self: a toast
  * @title: a title
  *
@@ -585,7 +559,8 @@ adw_toast_set_title (AdwToast   *self,
 
   adw_toast_set_custom_title (self, NULL);
 
-  g_set_str (&self->title, title);
+  g_clear_pointer (&self->title, g_free);
+  self->title = g_strdup (title);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_TITLE]);
 
@@ -593,7 +568,7 @@ adw_toast_set_title (AdwToast   *self,
 }
 
 /**
- * adw_toast_get_button_label:
+ * adw_toast_get_button_label: (attributes org.gtk.Method.get_property=button-label)
  * @self: a toast
  *
  * Gets the label to show on the button.
@@ -609,7 +584,7 @@ adw_toast_get_button_label (AdwToast *self)
 }
 
 /**
- * adw_toast_set_button_label:
+ * adw_toast_set_button_label: (attributes org.gtk.Method.set_property=button-label)
  * @self: a toast
  * @button_label: (nullable): a button label
  *
@@ -627,14 +602,17 @@ adw_toast_set_button_label (AdwToast   *self,
 {
   g_return_if_fail (ADW_IS_TOAST (self));
 
-  if (!g_set_str (&self->button_label, button_label))
+  if (!g_strcmp0 (self->button_label, button_label))
     return;
 
+  g_clear_pointer (&self->button_label, g_free);
+  self->button_label = g_strdup (button_label);
+
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_BUTTON_LABEL]);
 }
 
 /**
- * adw_toast_get_action_name:
+ * adw_toast_get_action_name: (attributes org.gtk.Method.get_property=action-name)
  * @self: a toast
  *
  * Gets the name of the associated action.
@@ -650,7 +628,7 @@ adw_toast_get_action_name (AdwToast *self)
 }
 
 /**
- * adw_toast_set_action_name:
+ * adw_toast_set_action_name: (attributes org.gtk.Method.set_property=action-name)
  * @self: a toast
  * @action_name: (nullable): the action name
  *
@@ -666,14 +644,17 @@ adw_toast_set_action_name (AdwToast   *self,
 {
   g_return_if_fail (ADW_IS_TOAST (self));
 
-  if (!g_set_str (&self->action_name, action_name))
+  if (!g_strcmp0 (self->action_name, action_name))
     return;
 
+  g_clear_pointer (&self->action_name, g_free);
+  self->action_name = g_strdup (action_name);
+
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_ACTION_NAME]);
 }
 
 /**
- * adw_toast_get_action_target_value: (get-property action-target)
+ * adw_toast_get_action_target_value: (attributes org.gtk.Method.get_property=action-target)
  * @self: a toast
  *
  * Gets the parameter for action invocations.
@@ -689,7 +670,7 @@ adw_toast_get_action_target_value (AdwToast *self)
 }
 
 /**
- * adw_toast_set_action_target_value: (set-property action-target)
+ * adw_toast_set_action_target_value: (attributes org.gtk.Method.set_property=action-target)
  * @self: a toast
  * @action_target: (nullable): the action target
  *
@@ -788,7 +769,7 @@ adw_toast_set_detailed_action_name (AdwToast   *self,
 }
 
 /**
- * adw_toast_get_priority:
+ * adw_toast_get_priority: (attributes org.gtk.Method.get_property=priority)
  * @self: a toast
  *
  * Gets priority for @self.
@@ -804,7 +785,7 @@ adw_toast_get_priority (AdwToast *self)
 }
 
 /**
- * adw_toast_set_priority:
+ * adw_toast_set_priority: (attributes org.gtk.Method.set_property=priority)
  * @self: a toast
  * @priority: the priority
  *
@@ -835,7 +816,7 @@ adw_toast_set_priority (AdwToast         *self,
 }
 
 /**
- * adw_toast_get_timeout:
+ * adw_toast_get_timeout: (attributes org.gtk.Method.get_property=timeout)
  * @self: a toast
  *
  * Gets timeout for @self.
@@ -851,7 +832,7 @@ adw_toast_get_timeout (AdwToast *self)
 }
 
 /**
- * adw_toast_set_timeout:
+ * adw_toast_set_timeout: (attributes org.gtk.Method.set_property=timeout)
  * @self: a toast
  * @timeout: the timeout
  *
@@ -878,7 +859,7 @@ adw_toast_set_timeout (AdwToast *self,
 }
 
 /**
- * adw_toast_get_custom_title:
+ * adw_toast_get_custom_title: (attributes org.gtk.Method.get_property=custom-title)
  * @self: a toast
  *
  * Gets the custom title widget of @self.
@@ -896,7 +877,7 @@ adw_toast_get_custom_title (AdwToast *self)
 }
 
 /**
- * adw_toast_set_custom_title:
+ * adw_toast_set_custom_title: (attributes org.gtk.Method.set_property=custom-title)
  * @self: a toast
  * @widget: (nullable): the custom title widget
  *
@@ -919,9 +900,6 @@ adw_toast_set_custom_title (AdwToast  *self,
   if (self->custom_title == widget)
     return;
 
-  if (widget)
-    g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
-
   g_object_freeze_notify (G_OBJECT (self));
 
   adw_toast_set_title (self, "");
@@ -970,48 +948,3 @@ adw_toast_set_overlay (AdwToast        *self,
 
   self->overlay = overlay;
 }
-
-/**
- * adw_toast_get_use_markup:
- * @self: a toast
- *
- * Gets whether to use Pango markup for the toast title.
- *
- * Returns: whether the toast uses markup
- *
- * Since: 1.4
- */
-gboolean
-adw_toast_get_use_markup (AdwToast *self)
-{
-  g_return_val_if_fail (ADW_IS_TOAST (self), FALSE);
-
-  return self->use_markup;
-}
-
-/**
- * adw_toast_set_use_markup:
- * @self: a toast
- * @use_markup: whether to use markup
- *
- * Whether to use Pango markup for the toast title.
- *
- * See also [func@Pango.parse_markup].
- *
- * Since: 1.4
- */
-void
-adw_toast_set_use_markup (AdwToast *self,
-                          gboolean  use_markup)
-{
-  g_return_if_fail (ADW_IS_TOAST (self));
-
-  use_markup = !!use_markup;
-
-  if (adw_toast_get_use_markup (self) == use_markup)
-    return;
-
-  self->use_markup = use_markup;
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_USE_MARKUP]);
-}
